package v1

import (
	"dy-admin/internal/pcmserver/bus/model/request"
	"dy-admin/internal/pcmserver/common"
	"dy-admin/pkg/bind"
	"dy-admin/pkg/rescode"
	"github.com/gin-gonic/gin"
	"github.com/gin-gonic/gin/binding"
)

type CronLogApi struct {
}

// DeleteCronLog
// @Tags      定时任务日志管理
// @Summary   批量删除定时任务日志
// @Security  ApiKeyAuth
// @accept    application/json
// @Produce   application/json
// @Param     data  body    request.DeleteCronLogReq true  "参数"
// @Success   200   {object}  rescode.ErrCode
// @Router    /bus/v1/device [delete]
func (api *CronLogApi) DeleteCronLog(c *gin.Context) {
	var req request.DeleteCronLogReq
	if err := bind.Bind(c, &req, binding.Query); err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	err := CronLogService.DeleteCronLog(req)
	if err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}
	rescode.WriteSuccessResponse(c, nil)
	return
}

// GetCronLogList
// @Tags      定时任务日志管理
// @Summary   分页获取定时任务日志
// @Security  ApiKeyAuth
// @accept    application/json
// @Produce   application/json
// @Param     data  body    request.DeviceLogSearch true  "参数"
// @Success   200   {object}  rescode.ErrCode
// @Router    /bus/v1/cron/list [get]
func (api *CronLogApi) GetCronLogList(c *gin.Context) {
	var pageInfo request.CronLogSearch
	if err := bind.Bind(c, &pageInfo, binding.Query); err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	list, total, err := CronLogService.GetCronLogList(pageInfo)
	if err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	rescode.WriteSuccessResponse(c, common.PageResult{
		List:     list,
		Total:    total,
		Page:     pageInfo.Page,
		PageSize: pageInfo.PageSize,
	})
	return
}
