package v1

import (
	"dy-admin/internal/pcmserver/bus/model"
	"dy-admin/internal/pcmserver/bus/model/request"
	"dy-admin/internal/pcmserver/common"
	"dy-admin/pkg/bind"
	"dy-admin/pkg/rescode"
	"github.com/gin-gonic/gin"
	"github.com/gin-gonic/gin/binding"
)

type DeviceLogApi struct {
}

// CreateDeviceLog
// @Tags      设备日志管理
// @Summary   创建日志(测试使用)
// @Security  ApiKeyAuth
// @accept    application/json
// @Produce   application/json
// @Param     data  body    model.DeviceLog true  "参数"
// @Success   200   {object}  rescode.ErrCode
// @Router    /bus/v1/device [post]
func (api *DeviceLogApi) CreateDeviceLog(c *gin.Context) {
	var log model.DeviceLog
	if err := bind.Bind(c, &log, binding.JSON); err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	err := DeviceLogService.CreateDeviceLog(log)
	if err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}
	rescode.WriteSuccessResponse(c, nil)
}

// DeleteDeviceLog
// @Tags      设备日志管理
// @Summary   批量删除设备日志
// @Security  ApiKeyAuth
// @accept    application/json
// @Produce   application/json
// @Param     data  body    request.DeleteDeviceLogReq true  "参数"
// @Success   200   {object}  rescode.ErrCode
// @Router    /bus/v1/device [delete]
func (api *DeviceLogApi) DeleteDeviceLog(c *gin.Context) {
	var req request.DeleteDeviceLogReq
	if err := bind.Bind(c, &req, binding.Query); err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	err := DeviceLogService.DeleteDeviceLog(req)
	if err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}
	rescode.WriteSuccessResponse(c, nil)
	return
}

// GetDeviceLogList
// @Tags      设备日志管理
// @Summary   分页获取设备日志
// @Security  ApiKeyAuth
// @accept    application/json
// @Produce   application/json
// @Param     data  body    request.DeviceLogSearch true  "参数"
// @Success   200   {object}  rescode.ErrCode
// @Router    /bus/v1/device/list [get]
func (api *DeviceLogApi) GetDeviceLogList(c *gin.Context) {
	var pageInfo request.DeviceLogSearch
	if err := bind.Bind(c, &pageInfo, binding.Query); err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	list, total, err := DeviceLogService.GetDeviceLogList(pageInfo)
	if err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	rescode.WriteSuccessResponse(c, common.PageResult{
		List:     list,
		Total:    total,
		Page:     pageInfo.Page,
		PageSize: pageInfo.PageSize,
	})
	return
}
