package model

import (
	"dy-admin/internal/pcmserver/common"
	"dy-admin/internal/pcmserver/global"
	systemModel "dy-admin/internal/pcmserver/sys/model"
	"dy-admin/pkg/log"
	"go.uber.org/zap"
	"gorm.io/gorm"
)

type Staff struct {
	common.Model
	DepartmentID  int    `json:"departmentId" gorm:"comment:'部门id'"`
	DeptName      string `json:"deptName" gorm:"-"`
	Name          string `json:"name" gorm:"size:128;comment:'人员姓名';index"`
	Sex           uint8  `json:"sex" gorm:"size:4;comment:'性别'"`
	Phone         string `json:"phone" gorm:"size:20;comment:'手机号';index"`
	CabinetID     int    `json:"cabinetId" gorm:"size:8;comment:'柜子id';index"`
	CabinetName   string `json:"cabinetName" gorm:"-"`
	GridDeviceID  int    `json:"gridDeviceId" gorm:"size:4;comment:'格子id';index"`
	VacationState uint8  `json:"vacationState" gorm:"size:4;comment:'1正常 2请假中'"`
	Remark        string `json:"remark" gorm:"size:512;comment:'备注'"`
	common.ControlBy
	common.ModelTime
}

func (Staff) TableName() string {
	return "bus_staffs"
}

func (s *Staff) AfterFind(db *gorm.DB) error {
	var cabinet Cabinet
	err := db.Where("id = ?", s.CabinetID).First(&cabinet).Error
	if err != nil {
		log.Error("err:", zap.Error(err))
	} else {
		s.CabinetName = cabinet.Name
	}

	var dept systemModel.Dept
	err = global.DB.Where("dept_id = ?", s.DepartmentID).First(&dept).Error
	if err != nil {
		log.Error("err:", zap.Error(err))
	} else {
		s.DeptName = dept.DeptName
	}
	return nil
}
