package sys

import (
	"dy-admin/internal/pcmserver/common"
	"dy-admin/internal/pcmserver/global"
	"dy-admin/internal/pcmserver/sys/model"
	"gorm.io/gorm/clause"
	"time"
)

var MenuInitEntities = []model.Menu{
	// 系统管理
	1: {MenuID: 1, MenuName: "Admin", Path: "/admin", Component: "RouteView", Title: "系统管理", Paths: "/0/1", MenuType: "M", ParentId: 0, NoCache: true, Sort: 1, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 系统管理-接口管理
	10: {MenuID: 10, MenuName: "AdminSysApi", Path: "/admin/sys-api", Title: "接口管理", Paths: "/0/1/10", MenuType: "C", ParentId: 1, NoCache: true, Sort: 10, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 系统管理-接口管理-接口按钮
	11: {MenuID: 11, MenuName: "", Title: "创建API", Paths: "/0/1/10/11", MenuType: "F", ParentId: 10, NoCache: true, Sort: 11, Visible: "1", SysApi: []model.Api{
		APIInitEntities[10],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	12: {MenuID: 12, MenuName: "", Title: "删除API", Paths: "/0/1/10/12", MenuType: "F", ParentId: 10, NoCache: true, Sort: 12, Visible: "1", SysApi: []model.Api{
		APIInitEntities[11],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	13: {MenuID: 13, MenuName: "", Title: "更新API", Paths: "/0/1/10/13", MenuType: "F", ParentId: 10, NoCache: true, Sort: 13, Visible: "1", SysApi: []model.Api{
		APIInitEntities[13], APIInitEntities[14],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	14: {MenuID: 14, MenuName: "", Title: "批量删除", Paths: "/0/1/10/14", MenuType: "F", ParentId: 10, NoCache: true, Sort: 14, Visible: "1", SysApi: []model.Api{
		APIInitEntities[15],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	15: {MenuID: 15, MenuName: "", Title: "查询列表", Paths: "/0/1/10/15", MenuType: "F", ParentId: 10, NoCache: true, Sort: 15, Visible: "1", SysApi: []model.Api{
		APIInitEntities[12],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 系统管理-部门管理
	20: {MenuID: 20, MenuName: "AdminSysDept", Path: "/admin/sys-dept", Title: "部门管理", Paths: "/0/1/20", MenuType: "C", ParentId: 1, NoCache: true, Sort: 20, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 系统管理-部门管理-接口按钮
	21: {MenuID: 21, MenuName: "", Title: "创建部门", Paths: "/0/1/20/21", MenuType: "F", ParentId: 20, NoCache: true, Sort: 21, Visible: "1", SysApi: []model.Api{
		APIInitEntities[20],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	22: {MenuID: 22, MenuName: "", Title: "删除部门", Paths: "/0/1/20/22", MenuType: "F", ParentId: 20, NoCache: true, Sort: 22, Visible: "1", SysApi: []model.Api{
		APIInitEntities[22],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	23: {MenuID: 23, MenuName: "", Title: "更新部门", Paths: "/0/1/20/23", MenuType: "F", ParentId: 20, NoCache: true, Sort: 23, Visible: "1", SysApi: []model.Api{
		APIInitEntities[21], APIInitEntities[12],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	24: {MenuID: 24, MenuName: "", Title: "查询列表", Paths: "/0/1/20/24", MenuType: "F", ParentId: 20, NoCache: true, Sort: 24, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 系统管理-菜单管理
	30: {MenuID: 30, MenuName: "AdminSysMenu", Path: "/admin/sys-menu", Title: "菜单管理", Paths: "/0/1/30", MenuType: "C", ParentId: 1, NoCache: true, Sort: 30, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 系统管理-菜单管理-接口按钮
	31: {MenuID: 31, MenuName: "", Title: "创建菜单", Paths: "/0/1/30/31", MenuType: "F", ParentId: 30, NoCache: true, Sort: 31, Visible: "1", SysApi: []model.Api{
		APIInitEntities[30],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	32: {MenuID: 32, MenuName: "", Title: "删除菜单", Paths: "/0/1/30/32", MenuType: "F", ParentId: 30, NoCache: true, Sort: 32, Visible: "1", SysApi: []model.Api{
		APIInitEntities[32],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	33: {MenuID: 33, MenuName: "", Title: "更新菜单", Paths: "/0/1/30/33", MenuType: "F", ParentId: 30, NoCache: true, Sort: 33, Visible: "1", SysApi: []model.Api{
		APIInitEntities[31], APIInitEntities[33],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	34: {MenuID: 34, MenuName: "", Title: "查询列表", Paths: "/0/1/30/34", MenuType: "F", ParentId: 30, NoCache: true, Sort: 34, Visible: "1", SysApi: []model.Api{
		APIInitEntities[34],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 系统管理-角色管理
	40: {MenuID: 40, MenuName: "AdminSysRole", Path: "/admin/sys-role", Title: "角色管理", Paths: "/0/1/40", MenuType: "C", ParentId: 1, NoCache: true, Sort: 40, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 系统管理-角色管理-接口按钮
	41: {MenuID: 41, MenuName: "", Title: "创建角色", Paths: "/0/1/40/41", MenuType: "F", ParentId: 40, NoCache: true, Sort: 41, Visible: "1", SysApi: []model.Api{
		APIInitEntities[40],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	42: {MenuID: 42, MenuName: "", Title: "删除角色", Paths: "/0/1/40/42", MenuType: "F", ParentId: 40, NoCache: true, Sort: 42, Visible: "1", SysApi: []model.Api{
		APIInitEntities[42],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	43: {MenuID: 43, MenuName: "", Title: "更新角色", Paths: "/0/1/40/43", MenuType: "F", ParentId: 40, NoCache: true, Sort: 43, Visible: "1", SysApi: []model.Api{
		APIInitEntities[34], APIInitEntities[45], APIInitEntities[46], APIInitEntities[44], APIInitEntities[41],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	44: {MenuID: 44, MenuName: "", Title: "更新数据权限", Paths: "/0/1/40/43", MenuType: "F", ParentId: 40, NoCache: true, Sort: 44, Visible: "1", SysApi: []model.Api{
		APIInitEntities[44], APIInitEntities[47],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	45: {MenuID: 45, MenuName: "", Title: "查询列表", Paths: "/0/1/40/45", MenuType: "F", ParentId: 40, NoCache: true, Sort: 45, Visible: "1", SysApi: []model.Api{
		APIInitEntities[43],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 系统管理-用户管理
	50: {MenuID: 50, MenuName: "AdminSysUser", Path: "/admin/sys-user", Title: "用户管理", Paths: "/0/1/50", MenuType: "C", ParentId: 1, NoCache: true, Sort: 50, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 系统管理-用户管理-接口按钮
	51: {MenuID: 51, MenuName: "", Title: "注册用户", Paths: "/0/1/50/51", MenuType: "F", ParentId: 50, NoCache: true, Sort: 51, Visible: "1", SysApi: []model.Api{
		APIInitEntities[43], APIInitEntities[50],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	52: {MenuID: 52, MenuName: "", Title: "删除用户", Paths: "/0/1/50/52", MenuType: "F", ParentId: 50, NoCache: true, Sort: 52, Visible: "1", SysApi: []model.Api{
		APIInitEntities[54],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	53: {MenuID: 53, MenuName: "", Title: "更新用户信息", Paths: "/0/1/50/53", MenuType: "F", ParentId: 50, NoCache: true, Sort: 53, Visible: "1", SysApi: []model.Api{
		APIInitEntities[43], APIInitEntities[56], APIInitEntities[55],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	54: {MenuID: 54, MenuName: "", Title: "重置密码", Paths: "/0/1/50/54", MenuType: "F", ParentId: 50, NoCache: true, Sort: 54, Visible: "1", SysApi: []model.Api{
		APIInitEntities[51],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	55: {MenuID: 55, MenuName: "", Title: "查询列表", Paths: "/0/1/50/55", MenuType: "F", ParentId: 50, NoCache: true, Sort: 55, Visible: "1", SysApi: []model.Api{
		APIInitEntities[53],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 日志管理-操作日志
	60: {MenuID: 60, MenuName: "AdminSysOperLog", Path: "/admin/sys-oper-log", Title: "操作日志", Paths: "/0/1/60", MenuType: "C", ParentId: 1, NoCache: true, Sort: 60, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 日志管理-操作日志-按钮
	61: {MenuID: 61, MenuName: "", Title: "查看详情", Paths: "/0/1/60/61", MenuType: "F", ParentId: 60, NoCache: true, Sort: 61, Visible: "1", SysApi: []model.Api{
		APIInitEntities[61],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	62: {MenuID: 62, MenuName: "", Title: "批量删除", Paths: "/0/1/60/62", MenuType: "F", ParentId: 60, NoCache: true, Sort: 62, Visible: "1", SysApi: []model.Api{
		APIInitEntities[63],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	63: {MenuID: 63, MenuName: "", Title: "删除单条", Paths: "/0/1/60/63", MenuType: "F", ParentId: 60, NoCache: true, Sort: 63, Visible: "1", SysApi: []model.Api{
		APIInitEntities[60],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	64: {MenuID: 64, MenuName: "", Title: "查询列表", Paths: "/0/1/60/64", MenuType: "F", ParentId: 60, NoCache: true, Sort: 64, Visible: "1", SysApi: []model.Api{
		APIInitEntities[61], APIInitEntities[62],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 日志管理-登录日志
	70: {MenuID: 70, MenuName: "AdminSysLoginLog", Path: "/admin/sys-login-log", Title: "登录日志", Paths: "/0/1/70", MenuType: "C", ParentId: 1, NoCache: true, Sort: 70, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 日志管理-登录日志-按钮
	71: {MenuID: 71, MenuName: "", Title: "查看详情", Paths: "/0/1/70/71", MenuType: "F", ParentId: 70, NoCache: true, Sort: 71, Visible: "1", SysApi: []model.Api{
		APIInitEntities[71],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	72: {MenuID: 72, MenuName: "", Title: "批量删除", Paths: "/0/1/70/72", MenuType: "F", ParentId: 70, NoCache: true, Sort: 72, Visible: "1", SysApi: []model.Api{
		APIInitEntities[70],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	73: {MenuID: 73, MenuName: "", Title: "查询列表", Paths: "/0/1/70/73", MenuType: "F", ParentId: 70, NoCache: true, Sort: 73, Visible: "1", SysApi: []model.Api{
		APIInitEntities[71], APIInitEntities[72],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},

	// 系统管理-影藏菜单
	80: {MenuID: 80, MenuName: "AdminSysShadow", Title: "影藏菜单", Paths: "/0/1/80", MenuType: "C", ParentId: 1, NoCache: true, Sort: 80, Visible: "0", SysApi: []model.Api{
		APIInitEntities[1070], APIInitEntities[1080], APIInitEntities[1090], APIInitEntities[1200], APIInitEntities[1300],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
}

var BusMenuEntities = []model.Menu{
	// 平台管理
	1000: {MenuID: 1000, MenuName: "Business", Path: "/business", Component: "RouteView", Title: "平台管理", Paths: "/0/1000", MenuType: "M", ParentId: 0, NoCache: true, Sort: 1000, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 平台管理-柜子管理
	1100: {MenuID: 1100, MenuName: "BusCabinet", Path: "/business/bus-cabinet", Title: "手机柜管理", Paths: "/0/1000/1100", MenuType: "C", ParentId: 1000, NoCache: true, Sort: 1100, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 平台管理-柜子管理-接口按钮
	1110: {MenuID: 1110, MenuName: "", Title: "创建", Paths: "/0/1000/1100/1110", MenuType: "F", ParentId: 1100, NoCache: true, Sort: 1110, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1000],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1120: {MenuID: 1120, MenuName: "", Title: "修改", Paths: "/0/1000/1100/1120", MenuType: "F", ParentId: 1100, NoCache: true, Sort: 1120, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1002], APIInitEntities[1001],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1130: {MenuID: 1130, MenuName: "", Title: "删除", Paths: "/0/1000/1100/1130", MenuType: "F", ParentId: 1100, NoCache: true, Sort: 1130, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1003],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1140: {MenuID: 1140, MenuName: "", Title: "开启状态切换", Paths: "/0/1000/1100/1140", MenuType: "F", ParentId: 1100, NoCache: true, Sort: 1140, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1005],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1150: {MenuID: 1150, MenuName: "BusCabinetTime", Path: "/business/bus-cabinetTime", Title: "柜子时间管理", Paths: "/0/1000/1100/1150", MenuType: "F", ParentId: 1100, NoCache: true, Sort: 1150, Visible: "0", SysApi: []model.Api{
		APIInitEntities[1012],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1151: {MenuID: 1151, MenuName: "", Title: "新增", Paths: "/0/1000/1100/1150/1151", MenuType: "F", ParentId: 1150, NoCache: true, Sort: 1151, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1010],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1152: {MenuID: 1152, MenuName: "", Title: "删除", Paths: "/0/1000/1100/1150/1152", MenuType: "F", ParentId: 1150, NoCache: true, Sort: 1152, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1013],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1153: {MenuID: 1153, MenuName: "", Title: "启用或禁用", Paths: "/0/1000/1100/1150/1153", MenuType: "F", ParentId: 1150, NoCache: true, Sort: 1153, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1011],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1160: {MenuID: 1160, MenuName: "", Title: "格子管理", Paths: "/0/1000/1100/1160", MenuType: "F", ParentId: 1100, NoCache: true, Sort: 1160, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1021],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1161: {MenuID: 1161, MenuName: "", Title: "开启格子", Paths: "/0/1000/1100/1160/1161", MenuType: "F", ParentId: 1160, NoCache: true, Sort: 1161, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1020],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1170: {MenuID: 1170, MenuName: "", Title: "查询列表", Paths: "/0/1000/1100/1170", MenuType: "F", ParentId: 1100, NoCache: true, Sort: 1170, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1004],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-人员管理
	1200: {MenuID: 1200, MenuName: "BusStaff", Path: "/business/bus-staff", Title: "人员管理", Paths: "/0/1000/1200", MenuType: "C", ParentId: 1000, NoCache: true, Sort: 1200, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-人员管理-接口按钮
	1210: {MenuID: 1210, MenuName: "", Title: "创建", Paths: "/0/1000/1200/1210", MenuType: "F", ParentId: 1200, NoCache: true, Sort: 1210, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1040],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1220: {MenuID: 1220, MenuName: "", Title: "更新", Paths: "/0/1000/1200/1220", MenuType: "F", ParentId: 1200, NoCache: true, Sort: 1220, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1041], APIInitEntities[1042],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1230: {MenuID: 1230, MenuName: "", Title: "删除", Paths: "/0/1000/1200/1230", MenuType: "F", ParentId: 1200, NoCache: true, Sort: 1230, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1043],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1240: {MenuID: 1240, MenuName: "", Title: "查询列表", Paths: "/0/1000/1200/1240", MenuType: "F", ParentId: 1200, NoCache: true, Sort: 1240, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1044],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-请假管理
	1300: {MenuID: 1300, MenuName: "BusLeave", Path: "/business/bus-leave", Title: "请假管理", Paths: "/0/1000/1300", MenuType: "C", ParentId: 1000, NoCache: true, Sort: 1300, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-请假管理-接口按钮
	1310: {MenuID: 1310, MenuName: "", Title: "创建", Paths: "/0/1000/1300/1310", MenuType: "F", ParentId: 1300, NoCache: true, Sort: 1310, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1030],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1320: {MenuID: 1320, MenuName: "", Title: "更新", Paths: "/0/1000/1300/1320", MenuType: "F", ParentId: 1300, NoCache: true, Sort: 1320, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1031], APIInitEntities[1032],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1330: {MenuID: 1330, MenuName: "", Title: "删除", Paths: "/0/1000/1300/1330", MenuType: "F", ParentId: 1300, NoCache: true, Sort: 1330, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1033],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1340: {MenuID: 1340, MenuName: "", Title: "查询列表", Paths: "/0/1000/1300/1340", MenuType: "F", ParentId: 1300, NoCache: true, Sort: 1340, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1034],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-时间管理
	1400: {MenuID: 1400, MenuName: "BusTime", Path: "/business/bus-time", Title: "时间管理", Paths: "/0/1000/1400", MenuType: "C", ParentId: 1000, NoCache: true, Sort: 1400, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1054],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-时间管理-工作时间
	1410: {MenuID: 1410, MenuName: "", Title: "工作时间", Paths: "/0/1000/1400/1410", MenuType: "F", ParentId: 1400, NoCache: true, Sort: 1410, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-时间管理-工作时间-按钮
	1411: {MenuID: 1411, MenuName: "", Title: "创建", Paths: "/0/1000/1400/1410/1411", MenuType: "F", ParentId: 1410, NoCache: true, Sort: 1411, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1050],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1412: {MenuID: 1412, MenuName: "", Title: "更新", Paths: "/0/1000/1400/1410/1412", MenuType: "F", ParentId: 1410, NoCache: true, Sort: 1412, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1051],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1413: {MenuID: 1413, MenuName: "", Title: "切换状态", Paths: "/0/1000/1400/1410/1413", MenuType: "F", ParentId: 1410, NoCache: true, Sort: 1413, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1052],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1414: {MenuID: 1414, MenuName: "", Title: "删除", Paths: "/0/1000/1400/1410/1414", MenuType: "F", ParentId: 1410, NoCache: true, Sort: 1414, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1053],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1415: {MenuID: 1415, MenuName: "", Title: "查询列表", Paths: "/0/1000/1400/1410/1415", MenuType: "F", ParentId: 1410, NoCache: true, Sort: 1415, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1054],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-时间管理-例外时间
	1420: {MenuID: 1420, MenuName: "", Title: "例外时间", Paths: "/0/1000/1400/1420", MenuType: "F", ParentId: 1400, NoCache: true, Sort: 1420, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-时间管理-例外时间-按钮
	1421: {MenuID: 1421, MenuName: "", Title: "创建", Paths: "/0/1000/1400/1420/1421", MenuType: "F", ParentId: 1420, NoCache: true, Sort: 1421, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1060],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1422: {MenuID: 1422, MenuName: "", Title: "更新", Paths: "/0/1000/1400/1420/1422", MenuType: "F", ParentId: 1420, NoCache: true, Sort: 1422, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1061],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1423: {MenuID: 1423, MenuName: "", Title: "切换状态", Paths: "/0/1000/1400/1420/1423", MenuType: "F", ParentId: 1420, NoCache: true, Sort: 1423, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1062],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1424: {MenuID: 1424, MenuName: "", Title: "删除", Paths: "/0/1000/1400/1420/1424", MenuType: "F", ParentId: 1420, NoCache: true, Sort: 1424, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1063],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1425: {MenuID: 1425, MenuName: "", Title: "查询列表", Paths: "/0/1000/1400/1420/1425", MenuType: "F", ParentId: 1420, NoCache: true, Sort: 1425, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1064],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-日志管理
	1500: {MenuID: 1500, MenuName: "BusLog", Path: "/businesslog", Component: "RouteView", Title: "日志管理", Paths: "/0/1000/1500", MenuType: "C", ParentId: 1000, NoCache: true, Sort: 1500, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-日志管理-开关门
	1510: {MenuID: 1510, MenuName: "BusOpenLog", Path: "/business/bus-open-log", Title: "开关门统计", Paths: "/0/1000/1500/1510", MenuType: "C", ParentId: 1500, NoCache: true, Sort: 1510, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1072],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-日志管理-开关门-按钮
	1511: {MenuID: 1511, MenuName: "", Title: "删除", Paths: "/0/1000/1500/1510/1511", MenuType: "F", ParentId: 1510, NoCache: true, Sort: 1511, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1071],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1512: {MenuID: 1512, MenuName: "", Title: "查询列表", Paths: "/0/1000/1500/1510/1512", MenuType: "F", ParentId: 1510, NoCache: true, Sort: 1512, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1072],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1513: {MenuID: 1513, MenuName: "", Title: "查询统计", Paths: "/0/1000/1500/1510/1513", MenuType: "F", ParentId: 1510, NoCache: true, Sort: 1513, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1073],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-日志管理-存物
	1520: {MenuID: 1520, MenuName: "BusStoreLog", Path: "/business/bus-store-log", Title: "存取物统计", Paths: "/0/1000/1500/1520", MenuType: "C", ParentId: 1500, NoCache: true, Sort: 1520, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-日志管理-存物-按钮
	1521: {MenuID: 1521, MenuName: "", Title: "删除", Paths: "/0/1000/1500/1520/1521", MenuType: "F", ParentId: 1520, NoCache: true, Sort: 1521, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1081],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1523: {MenuID: 1523, MenuName: "", Title: "查询列表", Paths: "/0/1000/1500/1520/1523", MenuType: "F", ParentId: 1520, NoCache: true, Sort: 1523, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1082],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1524: {MenuID: 1524, MenuName: "", Title: "查询统计", Paths: "/0/1000/1500/1520/1524", MenuType: "F", ParentId: 1520, NoCache: true, Sort: 1524, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1083],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-日志管理-警告记录
	1530: {MenuID: 1530, MenuName: "BusWarnLog", Path: "/business/bus-warn-log", Title: "警告统计", Paths: "/0/1000/1500/1530", MenuType: "C", ParentId: 1500, NoCache: true, Sort: 1530, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-日志管理-开关门-按钮
	1531: {MenuID: 1531, MenuName: "", Title: "删除", Paths: "/0/1000/1500/1530/1531", MenuType: "F", ParentId: 1530, NoCache: true, Sort: 1531, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1091],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1532: {MenuID: 1532, MenuName: "", Title: "查询列表", Paths: "/0/1000/1500/1530/1532", MenuType: "F", ParentId: 1530, NoCache: true, Sort: 1532, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1092],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1533: {MenuID: 1533, MenuName: "", Title: "查询统计", Paths: "/0/1000/1500/1530/1533", MenuType: "F", ParentId: 1530, NoCache: true, Sort: 1533, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1093],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 调试日志
	1600: {MenuID: 1600, MenuName: "SysLog", Path: "/syslog", Component: "RouteView", Title: "调式日志", Paths: "/0/1000/1600", MenuType: "C", ParentId: 1000, NoCache: true, Sort: 1600, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1610: {MenuID: 1610, MenuName: "SysDeviceLog", Path: "/syslog/device-log", Title: "设备日志", Paths: "/0/1000/1600/1610", MenuType: "C", ParentId: 1600, NoCache: true, Sort: 1610, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1611: {MenuID: 1611, MenuName: "", Title: "删除", Paths: "/0/1000/1600/1610/1611", MenuType: "F", ParentId: 1610, NoCache: true, Sort: 1611, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1301],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1612: {MenuID: 1612, MenuName: "", Title: "查询列表", Paths: "/0/1000/1600/1610/1612", MenuType: "F", ParentId: 1610, NoCache: true, Sort: 1612, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1302],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1620: {MenuID: 1620, MenuName: "MemCabinet", Path: "/syslog/mem-cabinet", Title: "内存信息", Paths: "/0/1000/1600/1610", MenuType: "C", ParentId: 1600, NoCache: true, Sort: 1620, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1621: {MenuID: 1621, MenuName: "", Title: "柜子信息", Paths: "/0/1000/1600/1620/1621", MenuType: "F", ParentId: 1620, NoCache: true, Sort: 1621, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1100],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1622: {MenuID: 1622, MenuName: "", Title: "定时任务", Paths: "/0/1000/1600/1620/1622", MenuType: "F", ParentId: 1620, NoCache: true, Sort: 1622, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1101],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1623: {MenuID: 1623, MenuName: "", Title: "配置信息", Paths: "/0/1000/1600/1620/1623", MenuType: "F", ParentId: 1620, NoCache: true, Sort: 1623, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1102],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},

	1640: {MenuID: 1640, MenuName: "SysCornLog", Path: "/syslog/cron-log", Title: "定时任务日志", Paths: "/0/1000/1600/1640", MenuType: "C", ParentId: 1600, NoCache: true, Sort: 1640, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1641: {MenuID: 1641, MenuName: "", Title: "删除", Paths: "/0/1000/1600/1640/1641", MenuType: "F", ParentId: 1640, NoCache: true, Sort: 1641, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1401],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1642: {MenuID: 1642, MenuName: "", Title: "查询列表", Paths: "/0/1000/1600/1640/1642", MenuType: "F", ParentId: 1640, NoCache: true, Sort: 1642, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1402],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},

	1650: {MenuID: 1650, MenuName: "SysConnectLog", Path: "/syslog/connect-log", Title: "连接日志", Paths: "/0/1000/1600/1650", MenuType: "C", ParentId: 1600, NoCache: true, Sort: 1650, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1651: {MenuID: 1651, MenuName: "", Title: "删除", Paths: "/0/1000/1600/1650/1651", MenuType: "F", ParentId: 1650, NoCache: true, Sort: 1651, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1501],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1652: {MenuID: 1652, MenuName: "", Title: "查询列表", Paths: "/0/1000/1600/1650/1652", MenuType: "F", ParentId: 1650, NoCache: true, Sort: 1652, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1502],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-配置管理
	1700: {MenuID: 1700, MenuName: "BusConfig", Path: "/business/bus-config", Title: "配置管理", Paths: "/0/1000/1700", MenuType: "C", ParentId: 1000, NoCache: true, Sort: 1700, Visible: "1", SysApi: []model.Api{}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	// 手机柜管理-人员管理-接口按钮
	1710: {MenuID: 1710, MenuName: "", Title: "更新", Paths: "/0/1000/1700/1710", MenuType: "F", ParentId: 1700, NoCache: true, Sort: 1710, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1601],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
	1720: {MenuID: 1720, MenuName: "", Title: "查询", Paths: "/0/1000/1700/1720", MenuType: "F", ParentId: 1700, NoCache: true, Sort: 1720, Visible: "1", SysApi: []model.Api{
		APIInitEntities[1602],
	}, ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1}, ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()}},
}

func initMenuData() error {
	entities := make([]model.Menu, 0)
	for _, sysEntity := range MenuInitEntities {
		if sysEntity.MenuID != 0 {
			entities = append(entities, sysEntity)
		}
	}
	for _, busEntity := range BusMenuEntities {
		if busEntity.MenuID != 0 {
			entities = append(entities, busEntity)
		}
	}
	if err := global.DB.Clauses(clause.OnConflict{UpdateAll: true}).Create(&entities).Error; err != nil {
		return err
	}
	return nil
}
