package router

import (
	_ "dy-admin/docs"
	"dy-admin/internal/pcmserver/config"
	"dy-admin/internal/pcmserver/global"
	"dy-admin/internal/pcmserver/pkg/my_middleware"
	"github.com/gin-gonic/gin"
	swaggerFiles "github.com/swaggo/files"
	ginSwagger "github.com/swaggo/gin-swagger"
)

func LoadRouter(cfg *config.Config, engine *gin.Engine) {
	systemRouter := AppGroupRouter.System
	businessRouter := AppGroupRouter.Business
	engine.GET("/swagger/*any", ginSwagger.WrapHandler(swaggerFiles.Handler))

	publicGroup := engine.Group("")
	{
		systemRouter.InitBaseRouter(publicGroup) // 基础路由，不做鉴权。

	}

	privateGroup := engine.Group("")

	// 系统路由
	sysPrivateGroup := privateGroup.Group("sys")
	sysPrivateGroup.Use(my_middleware.JWTAuth(global.JWT), my_middleware.CasbinHandler(global.JWT))
	{
		systemRouter.InitApiRouter(sysPrivateGroup)
		systemRouter.InitDeptRouter(sysPrivateGroup)
		systemRouter.InitMenuRouter(sysPrivateGroup)
		systemRouter.InitRoleRouter(sysPrivateGroup)
		systemRouter.InitUserRouter(sysPrivateGroup)
		systemRouter.InitOperationRecordRouter(sysPrivateGroup)
		systemRouter.InitLoginRecordRouter(sysPrivateGroup)
	}

	// 业务路由
	busPrivateGroup := privateGroup.Group("bus")

	{
		businessRouter.InitStatisticRouter(busPrivateGroup)
	}

	busPrivateGroup.Use(my_middleware.JWTAuth(global.JWT), my_middleware.CasbinHandler(global.JWT))
	{
		businessRouter.InitExampleRouter(busPrivateGroup)
		businessRouter.InitLeaveLogRouter(busPrivateGroup)
		businessRouter.InitStaffRouter(busPrivateGroup)
		businessRouter.InitGridRouter(busPrivateGroup)
		businessRouter.InitCabinetRouter(busPrivateGroup)
		businessRouter.InitGridOpenLogRouter(busPrivateGroup)
		businessRouter.InitGridStoreLogRouter(busPrivateGroup)
		businessRouter.InitGridWarnLogRouter(busPrivateGroup)
		businessRouter.InitCabinetTimeRouter(busPrivateGroup)
		businessRouter.InitWorkTimeRouter(busPrivateGroup)
		businessRouter.InitSpecTimeRouter(busPrivateGroup)
		businessRouter.InitMemoryInfoRouter(busPrivateGroup)
		businessRouter.InitDeviceLogRouter(busPrivateGroup)
		businessRouter.InitCronLogRouter(busPrivateGroup)
		businessRouter.InitConnectLogRouter(busPrivateGroup)
		businessRouter.InitBusConfigRouter(busPrivateGroup)
	}

}
